@@ -517,12 +517,4 @@ class Matching(c.Cog, name="マッチングテスト", command_attrs=dict(hidden
             #削除完了のメッセージを送信
             await self.send_deleter(payload, base_data)
             #dbのデータを削除
-            await self.matching.delete(paneru_mes=mes.id, member=payload.member.id, channel = target.id, mes=data['mes'])
-
-
-
-def setup(bot):
-    bot.add_cog(Matching(bot))
-    bot.add_table(matching_table)
-    bot.add_table(matchi_table_)
-    bot.add_table(baserole_table)
\ No newline at end of file
+            await self.matching.delete(paneru_mes=mes.id, member=payload.member.id, channel = target.id, mes=data['mes'])
\ No newline at end of file
