@@ -3,7 +3,7 @@ from discord import TextChannel, Embed, errors
 from asyncpgw import general
 
 #pylint: disable=import-error
-from samep.cogs.utils import embed, paid, err
+from samep.cogs.utils import embed, err
 
 auto_reaction_table = """auto_reaction(
     server bigint,
